@@ -3,6 +3,6 @@ from .request import RequestClient
 from .statistics import *
 from .utils import *
 
-__version__ = "0.6.2"
-__author__ = "apex2504"
+__version__ = "0.6.4"
+__author__ = "Rob Wainwright // apex2504"
 __license__ = "MIT"
\ No newline at end of file
