@@ -2,9 +2,10 @@ GLOBAL_DATA = '{}/all'
 ALL_COUNTRIES = '{}/countries'
 SORTED_COUNTRIES = '{}/countries?sort={}'
 COUNTRY_DATA = '{}/countries/{}'
-STATES = '{}/states'
-HISTORICAL_COUNTRY = '{}/v2/historical/{}'
-HISTORICAL_PROVINCE = '{}/v2/historical/{}/{}'
+ALL_STATES = '{}/states'
+SINGLE_STATE = '{}/states/{}'
+HISTORICAL_COUNTRY = '{}/v2/historical/{}?lastdays={}'
+HISTORICAL_PROVINCE = '{}/v2/historical/{}/{}?lastdays={}'
 JHU_CSSE = '{}/v2/jhucsse'
 JHU_CSSE_COUNTIES = '{}/v2/jhucsse/counties/{}'
 YESTERDAY = '{}/yesterday'
\ No newline at end of file
